﻿using System;

//TODO: Add PCMonitorClient.dll from the PC Monitor installation folder as a reference to your project
using MM.Monitor.Client;

namespace MM.Monitor.Plugins
{
    public class ComputerDetails : ClientPlugin
    {
        private int invocationCount;        
        private const int COMMAND_SEND_TEST_NOTIFICATION = 1;
        private const int COMMAND_RESET_INVOCATIONS_COUNT = 2;

        private const int PAGE_FIRST = 1;
        private const int PAGE_SECOND = 2;

        public override Groups GetAdditionalComputerDetails()
        {
            /// Use this method to define custom groups that can contain simple items or command items
            /// The groups will be dispayed on the computer details page
            /// Make sure you assign unique command Ids for each command and the Id is greater than zero
            
            invocationCount++;

            Groups groups = new Groups();
            Group firstGroup = new Group("Plugin Demo Group");
            
            firstGroup.Items.Add(new SimpleItem(invocationCount.ToString(), "Plugin Invocation Count"));

            if (CanSendNotifications)
            {
                firstGroup.Items.Add(new CommandItem(COMMAND_SEND_TEST_NOTIFICATION, "Send a Test Notification"));
            }

            groups.Add(firstGroup);

            Group secondGroup = new Group("Plugin Computer Details");

            secondGroup.Items.Add(new CommandItem(COMMAND_RESET_INVOCATIONS_COUNT, "Reset Invocation Count"));
            secondGroup.Items.Add(new SimpleItem(System.Environment.MachineName, "Computer Name"));
            secondGroup.Items.Add(new SimpleItem(System.Environment.OSVersion.ToString(), "OS Version"));
            secondGroup.Items.Add(new SimpleItem(System.Environment.ProcessorCount.ToString(), "Processor Count", SimpleItemStyle.INFORMATION));
            secondGroup.Items.Add(new SimpleItem(System.Environment.SystemDirectory, "System Directory", SimpleItemStyle.WARNING));
            secondGroup.Items.Add(new SimpleItem(System.Environment.UserName, "User Name", SimpleItemStyle.ERROR));
            secondGroup.Items.Add(new SimpleItem(System.Environment.UserDomainName, "User Domain Name"));            

            groups.Add(secondGroup);

            Group thirdGroup = new Group("Plugin Pages");
            thirdGroup.Items.Add(new PageItem(PAGE_FIRST, "Page 1", "This is a page"));

            groups.Add(thirdGroup);

            return groups;
        }
        public override Groups GetPageDetails(int pageId)
        {
            Groups groups = new Groups();

            if (pageId == PAGE_FIRST)
            {
                Group firstGroup = new Group("First Page Items");
                firstGroup.Items.Add(new SimpleItem("1", "Simple Value"));
                if (CanSendNotifications)
                {
                    firstGroup.Items.Add(new CommandItem(COMMAND_SEND_TEST_NOTIFICATION, "Send a test notification"));
                }
                firstGroup.Items.Add(new PageItem(PAGE_SECOND, "Page 2", "This is another page"));
                groups.Add(firstGroup);

                Group secondGroup = new Group("Plugin Input Control");
                secondGroup.Items.Add(new TextInputItem("StringInputOnPage", "String", "Please enter a string"));
                secondGroup.Items.Add(new NumberInputItem("NumberInputOnPage", "Number", "Please enter a number"));
                secondGroup.Items.Add(new DateInputItem("DateInputOnPage", "Date", "Please enter a date"));
                secondGroup.Items.Add(new TimeInputItem("TimeInputOnPage", "Time", "Please enter a time"));
                secondGroup.Items.Add(new DateTimeInputItem("DateTimeInputOnPage", "DateTime", "Please enter a date and time"));

                PickListItems items = new PickListItems();
                items.Add(new PickListItem(1, "Item 1 with a very very very very very very very very very very very very very very... looooooooooong text"));
                items.Add(new PickListItem(2, "Item 2", "With description."));
                items.Add(new PickListItem(3, "Item 3"));
                secondGroup.Items.Add(new PickListInputItem("PickListOnPage", "Pick", "Please select an item", items));

                groups.Add(secondGroup);
            }
            else if (pageId == PAGE_SECOND)
            {
                Group firstGroup = new Group("Second Page Items");
                firstGroup.Items.Add(new SimpleItem("2", "Simple Value"));
                if (CanSendNotifications)
                {
                    firstGroup.Items.Add(new CommandItem(COMMAND_SEND_TEST_NOTIFICATION, "Send a test notification"));
                }
                groups.Add(firstGroup);
            }

            return groups;
        }
        public override void CommandReceived(int commandId)
        {
            /// This method is called when a command item is pressed in the mobile application / web application

            if (commandId == COMMAND_SEND_TEST_NOTIFICATION)
            {
                base.SendNotificationToAllDevices("This is a test notification", NotificationPriority.NORMAL);                
            }
            else if (commandId == COMMAND_RESET_INVOCATIONS_COUNT)
            {
                invocationCount = 0;
            }
        }
        public override void PageCommandReceived(int pageId, int commandId)
        {
            /// This method is called when a page command item is pressed in the mobile application / web application
            
            if (commandId == COMMAND_SEND_TEST_NOTIFICATION)
            {
                if (pageId == PAGE_FIRST)
                {
                    base.SendNotificationToAllDevices("This is a test notification from the 1st Page Client API", NotificationPriority.CRITICAL);
                }
                else if (pageId == PAGE_SECOND)
                {
                    base.SendNotificationToAllDevices("This is a test notification from the 2nd Page Client API", NotificationPriority.CRITICAL);
                }
            }
        }
        public override void NotificationDeleted()
        {
            /// This method is called when the notification sent from this plugin was deleted.
            /// As the notification has been deleted you can now send a new notification            
        }
        public override string GetPluginName()
        {
            return "Computer Details";
        }
        public override string GetPluginDescription()
        {
            return "Shows additional computer details and commands";
        }        
    }
}
