﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using MM.Monitor.Client;

namespace MM.Monitor.Plugins
{
    public partial class MoreInfoConfiguration : Form
    {
        public class InfoItem
        {
            public string Title;
            public string Subtitle;

            public InfoItem()
                : this("", "")
            {
            }
            public InfoItem(string title, string subtitle)
            {
                Title = title;
                Subtitle = subtitle;
            }
        }

        private IDataStore dataStore;

        public MoreInfoConfiguration(IDataStore dataStore)
        {
            this.dataStore = dataStore;

            InitializeComponent();

            LoadValues();
        }

        private void LoadValues()
        {
            int count = 0;
            bool hasDetails = int.TryParse(dataStore.GetValueForKey("Count"), out count);

            if (hasDetails)
            {
                for (int x = 1; x <= count; x++)
                {
                    AddItem(dataStore.GetValueForKey("Title" + x.ToString()), dataStore.GetValueForKey("Subtitle" + x.ToString()));
                }
            }

            UpdateControlsState();
        }

        private void AddItem(string title, string subtitle)
        {
            if (title == null)
                title = "";
            if (subtitle == null)
                subtitle = "";

            AddItem(new InfoItem(title, subtitle));
        }
        private void AddItem(InfoItem infoItem)
        {
            ListViewItem item = listView.Items.Add(new ListViewItem(infoItem.Title));
            item.SubItems.Add(infoItem.Subtitle.Replace("\r\n", " "));
            item.Tag = infoItem;
        }

        private void listView_SelectedIndexChanged(object sender, EventArgs e)
        {
            UpdateControlsState();
        }

        private void UpdateControlsState()
        {
            bEdit.Enabled = listView.SelectedItems.Count == 1;
            bRemove.Enabled = listView.SelectedItems.Count > 0;
        }

        private void bAdd_Click(object sender, EventArgs e)
        {
            EditModeInfoItem editor = new EditModeInfoItem();
            if (editor.ShowDialog() == System.Windows.Forms.DialogResult.OK)
            {
                AddItem(editor.EditedInfoItem);
            }

            UpdateControlsState();
        }

        private void bEdit_Click(object sender, EventArgs e)
        {
            EditSelectedItem();
        }

        private void EditSelectedItem()
        {
            if (listView.SelectedItems.Count != 1)
                return;

            EditModeInfoItem editor = new EditModeInfoItem((InfoItem)listView.SelectedItems[0].Tag);
            if (editor.ShowDialog() == System.Windows.Forms.DialogResult.OK)
            {
                listView.SelectedItems[0].Text = editor.EditedInfoItem.Title;
                listView.SelectedItems[0].SubItems[1].Text = editor.EditedInfoItem.Subtitle;
                listView.SelectedItems[0].Tag = editor.EditedInfoItem;
            }

            UpdateControlsState();
        }

        private void bRemove_Click(object sender, EventArgs e)
        {            
            foreach (ListViewItem item in listView.SelectedItems)
            {
                listView.Items.Remove(item);
            }

            UpdateControlsState();
        }

        private void bOK_Click(object sender, EventArgs e)
        {
            SaveValues();
        }

        private void SaveValues()
        {
            dataStore.SetValueForKey("Count", listView.Items.Count.ToString());
            int index = 1;
            foreach(ListViewItem item in listView.Items)
            {
                InfoItem infoItem = (InfoItem)item.Tag;
                dataStore.SetValueForKey("Title" + index.ToString(), infoItem.Title);
                dataStore.SetValueForKey("Subtitle" + index.ToString(), infoItem.Subtitle);

                index++;
            }
        }

        private void listView_DoubleClick(object sender, EventArgs e)
        {
            EditSelectedItem();
        }
    }
}
